This Project requires Python 3.10.4 or newer.

### Using pip

```shell
pip install anaplan-sdk
```

### Using poetry

```shell
poetry add anaplan-sdk
```

### Dependencies

Anaplan SDK has few dependencies:

- [httpx](https://www.python-httpx.org/): HTTP Client.
- [pydantic](https://pypi.org/project/pydantic/): Data Models and validation.
- [cryptography](https://github.com/pyca/cryptography): Cryptographic Algorithms.
